@@ -18,6 +18,7 @@
 #include "expression.h"
 
 #include <QDomElement>
+#include <QCoreApplication>
 
 #include "explexer.h"
 #include "expressionparser.h"
@@ -25,7 +26,6 @@
 #include "value.h"
 #include "vector.h"
 #include "variable.h"
-#include "expressionwriter.h"
 #include "stringexpressionwriter.h"
 #include "htmlexpressionwriter.h"
 #include "mathmlexpressionwriter.h"
@@ -34,7 +34,7 @@
 #include "analitzautils.h"
 #include "apply.h"
 #include "customobject.h"
-#include "localize.h"
+
 #include "matrix.h"
 
 using namespace Analitza;
@@ -50,7 +50,7 @@ public:
 	
 	Object* branch(const QDomElement& elem);
 	
-	template <class T>
+	template <class T, class Tcontained = Object>
 	T* addElements(T* v, const QDomElement* elem)
 	{
 		QDomNode n = elem->firstChild();
@@ -59,7 +59,7 @@ public:
 				Object* ob= branch(n.toElement()); //TODO: We should do that better
 				
 				if(ob && canAdd(v, ob)) {
-					v->appendBranch(ob);
+					v->appendBranch(static_cast<Tcontained*>(ob));
 				} else {
 // 					delete ob;
 					delete v;
@@ -159,21 +159,23 @@ bool Expression::ExpressionPrivate::check(const Apply* c)
 	if(((op.nparams()<0 && cnt<=1) || (op.nparams()>-1 && cnt!=op.nparams())) && (opt!=Operator::minus || cnt==0) && opt!=Operator::function)
 	{
 		if(op.nparams()<0)
-			m_err << i18n("<em>%1</em> needs at least 2 parameters", op.toString());
+			m_err << QCoreApplication::tr("<em>%1</em> needs at least 2 parameters").arg(op.toString());
 		else
-			m_err << i18n("<em>%1</em> requires %2 parameters", op.toString(), op.nparams());
+			m_err << QCoreApplication::tr("<em>%1</em> requires %2 parameters")
+											.arg(op.toString())
+											.arg(op.nparams());
 		ret=false;
 	}
 	
 	if(op.isBounded() && !c->hasBVars()) {
-		m_err << i18n("Missing boundary for '%1'", op.toString());
+		m_err << QCoreApplication::tr("Missing boundary for '%1'").arg(op.toString());
 	} else if(!op.isBounded() && c->hasBVars()) {
-		m_err << i18n("Unexpected bounding for '%1'", op.toString());
+		m_err << QCoreApplication::tr("Unexpected bounding for '%1'").arg(op.toString());
 	}
 	
 	if(op.isBounded() && op!=Operator::diff) {
 		if(!(c->ulimit() && c->dlimit()) && !c->domain()) {
-			m_err << i18n("<em>%1</em> missing bounds on '%2'", c->bvarStrings().join(" "), op.toString());
+			m_err << QCoreApplication::tr("<em>%1</em> missing bounds on '%2'").arg(c->bvarStrings().join(" ")).arg(op.toString());
 		}
 	}
 	
@@ -195,7 +197,7 @@ bool Expression::ExpressionPrivate::check(const Container* c)
 	switch(c->containerType()) {
 		case Container::declare:
 			if(c->m_params.size()!=2) {
-				m_err << i18n("Wrong declare");
+				m_err << QCoreApplication::tr("Wrong declare");
 				ret=false;
 			}
 			break;
@@ -205,7 +207,7 @@ bool Expression::ExpressionPrivate::check(const Container* c)
 	}
 	
 	if(c->isEmpty() && c->containerType()!=Container::math) {
-		m_err << i18n("Empty container: %1", c->tagName());
+		m_err << QCoreApplication::tr("Empty container: %1").arg(c->tagName());
 		ret=false;
 	}
 	
@@ -223,7 +225,7 @@ bool Expression::ExpressionPrivate::canAdd(const Object* where, const Object* br
 			bool isPiecewise=where->type()==Object::container
 				&& static_cast<const Container*>(where)->containerType()==Container::piecewise;
 			if(!isPiecewise) {
-				m_err << i18nc("there was a conditional outside a condition structure",
+				m_err << QCoreApplication::translate("there was a conditional outside a condition structure",
 								"We can only have conditionals inside piecewise structures.");
 				correct=false;
 			}
@@ -239,7 +241,7 @@ bool Expression::ExpressionPrivate::canAdd(const Object* where, const Object* br
 			
 			if(bvars.contains(var->name())) {
 				correct=false;
-				m_err << i18n("Cannot have two parameters with the same name like '%1'.", var->name());
+				m_err << QCoreApplication::tr("Cannot have two parameters with the same name like '%1'.").arg(var->name());
 			}
 		}
 	}
@@ -254,7 +256,7 @@ bool Expression::ExpressionPrivate::canAdd(const Object* where, const Object* br
 				isCondition=ct==Container::piece || ct==Container::otherwise;
 				
 				if(cWhere->extractType(Container::otherwise)) {
-					m_err << i18nc("this is an error message. otherwise is the else in a mathml condition",
+					m_err << QCoreApplication::translate("this is an error message. otherwise is the else in a mathml condition",
 						"The <em>otherwise</em> parameter should be the last one");
 					correct=false;
 				}
@@ -262,23 +264,43 @@ bool Expression::ExpressionPrivate::canAdd(const Object* where, const Object* br
 			}
 			
 			if(!isCondition) {
-				m_err << i18nc("there was an element that was not a conditional inside a condition",
-									"%1 is not a proper condition inside the piecewise", branch->toString());
+				m_err << QCoreApplication::translate("there was an element that was not a conditional inside a condition",
+									"%1 is not a proper condition inside the piecewise").arg(branch->toString());
 				correct=false;
 			}
 			
 		} else if(cWhere->containerType()==Container::declare && cWhere->isEmpty() && branch->type()!=Object::variable) {
-			m_err << i18n("We can only declare variables");
+			m_err << QCoreApplication::tr("We can only declare variables");
 			correct=false;
 		}
 		
 		if(cWhere->containerType()==Container::bvar) {
 			if(branch->type()!=Object::variable) {
-				m_err << i18n("We can only have bounded variables");
+				m_err << QCoreApplication::tr("We can only have bounded variables");
+				correct=false;
+			}
+		}
+	} else 
+		if(where->type()==Object::matrix) {
+			if(branch->type()==Object::matrixrow) {
+				const Matrix *matrix = static_cast<const Matrix*>(where);
+				const MatrixRow *matrixrow = static_cast<const MatrixRow*>(branch);
+				
+				if (matrixrow->size() == 0) {
+					m_err << QCoreApplication::tr("Do not want empty matrixrow elements");
+					correct=false;
+				}
+				
+				if (matrix->rowCount() != 0)
+					if (static_cast<MatrixRow*>(matrix->rows().first())->size() != matrixrow->size()) {
+						m_err << QCoreApplication::tr("All matrixrow elements must have the same size");
+						correct=false;
+					}
+			} else {
+				m_err << QCoreApplication::tr("The matrix must contain only matrixrow elements");
 				correct=false;
 			}
 		}
-	}
 	
 	Q_ASSERT(correct || !m_err.isEmpty());
 	
@@ -394,7 +416,7 @@ bool Expression::setMathML(const QString & s)
 	QDomDocument doc;
 	
 	if (!doc.setContent(s)) {
-		d->m_err << i18n("Error while parsing: %1", s);
+		d->m_err << QCoreApplication::tr("Error while parsing: %1").arg(s);
 		return false;
 	}
 	
@@ -425,23 +447,23 @@ Object* Expression::ExpressionPrivate::branch(const QDomElement& elem)
 				}
 				ret = c;
 			} else
-				m_err << i18nc("An error message", "Container unknown: %1", elem.tagName());
+				m_err << QCoreApplication::translate("An error message", "Container unknown: %1").arg(elem.tagName());
 		}	break;
 		case Object::value:
 			num= new Cn(0.);
 			if(!num->setValue(elem)) {
 				delete num;
-				m_err<< i18n("Cannot codify the %1 value.", elem.text());
+				m_err<< QCoreApplication::tr("Cannot codify the %1 value.").arg(elem.text());
 			} else
 				ret = num;
 			break;
 		case Object::oper:
 			if(elem.hasChildNodes()) {
-				m_err << i18n("The %1 operator cannot have child contexts.", elem.tagName());
+				m_err << QCoreApplication::tr("The %1 operator cannot have child contexts.").arg(elem.tagName());
 			} else {
 				Operator::OperatorType type=Operator::toOperatorType(elem.tagName());
 				if(type==Operator::none)
-					m_err << i18n("The element '%1' is not an operator.", elem.tagName());
+					m_err << QCoreApplication::tr("The element '%1' is not an operator.").arg(elem.tagName());
 				else
 					ret = op = new Operator(type);
 			}
@@ -454,7 +476,7 @@ Object* Expression::ExpressionPrivate::branch(const QDomElement& elem)
 		case Object::vector: {
 			ret=addElements<Vector>(new Vector(elem.childNodes().count()), &elem);
 			if(elem.childNodes().count()==0) {
-				m_err << i18n("Do not want empty vectors");
+				m_err << QCoreApplication::tr("Do not want empty vectors");
 			}
 // 			qDebug() << "PEEEEEEU" << v->size();
 		}	break;
@@ -462,10 +484,16 @@ Object* Expression::ExpressionPrivate::branch(const QDomElement& elem)
 			ret=addElements<List>(new List, &elem);
 			break;
 		case Object::matrix:
-			ret=addElements<Matrix>(new Matrix, &elem);
+			ret=addElements<Matrix, MatrixRow>(new Matrix, &elem);
+			if(elem.childNodes().count()==0) {
+				m_err << QCoreApplication::tr("Do not want empty matrices");
+			}
 			break;
 		case Object::matrixrow:
 			ret=addElements<MatrixRow>(new MatrixRow, &elem);
+			if(elem.childNodes().count()==0) {
+				m_err << QCoreApplication::tr("Do not want empty matrixrow elements");
+			}
 			break;
 		case Object::apply: {
 			Apply *a=addElements<Apply>(new Apply, &elem);
@@ -477,8 +505,8 @@ Object* Expression::ExpressionPrivate::branch(const QDomElement& elem)
 		}	break;
 		case Object::none:
 		case Object::custom:
-			m_err << i18nc("Error message due to an unrecognized input",
-							  "Not supported/unknown: %1", elem.tagName());
+			m_err << QCoreApplication::translate("Error message due to an unrecognized input",
+							  "Not supported/unknown: %1").arg(elem.tagName());
 			break;
 	}
 	
@@ -489,26 +517,26 @@ Object* Expression::ExpressionPrivate::branch(const QDomElement& elem)
 QString Expression::toHtml() const
 {
 	Q_ASSERT(isCorrect());
-	return HtmlExpressionWriter(d->m_tree).result();
+	return HtmlExpressionWriter(d->m_tree).result().toString();
 }
 
 QString Expression::toMathMLPresentation() const
 {
 	Q_ASSERT(isCorrect());
-	return MathMLPresentationExpressionWriter(d->m_tree).result();
+	return MathMLPresentationExpressionWriter(d->m_tree).result().toString();
 }
 
 QString Expression::toMathML() const
 {
 	Q_ASSERT(isCorrect());
-	return MathMLExpressionWriter(d->m_tree).result();
+	return MathMLExpressionWriter(d->m_tree).result().toString();
 }
 
 QString Expression::toString() const
 {
 	Q_ASSERT(isCorrect());
 	StringExpressionWriter s(d->m_tree);
-	return s.result();
+	return s.result().toString();
 }
 
 enum Object::ObjectType Expression::whatType(const QString& tag)
@@ -579,7 +607,7 @@ QStringList Expression::bvarList() const
 Cn Expression::toReal() const
 {
 	Object* tree=d->m_tree;
-	if(KDE_ISLIKELY(tree && tree->type()==Object::value))
+	if(Q_LIKELY(tree && tree->type()==Object::value))
 		return *static_cast<Cn*>(tree);
 	else {
 		qDebug() << "trying to return not a real value as real:" << (tree ? tree->toString() : "null");
@@ -590,7 +618,7 @@ Cn Expression::toReal() const
 QString Expression::stringValue() const
 {
 	Object* tree=d->m_tree;
-	if(KDE_ISLIKELY(d->m_tree && d->m_tree->type()==Object::list))
+	if(Q_LIKELY(d->m_tree && d->m_tree->type()==Object::list))
 		return AnalitzaUtils::listToString(static_cast<const List*>(tree));
 	else {
 		qDebug() << "trying to return not a string value as string:" << (tree ? tree->toString() : "null");
@@ -721,6 +749,12 @@ bool Expression::isVector() const
 	return o && o->type()==Container::vector;
 }
 
+bool Expression::isMatrix() const
+{
+	Object* o = actualRoot(d->m_tree);
+	return o && o->type()==Container::matrix;
+}
+
 bool Expression::isList() const
 {
 	Object* o = actualRoot(d->m_tree);
@@ -873,7 +907,7 @@ Expression Expression::constructCustomObject(const QVariant& custom, CustomObjec
 QVariant Expression::customObjectValue() const
 {
 	Object* tree=d->m_tree;
-	if(KDE_ISLIKELY(tree && tree->type()==Object::custom))
+	if(Q_LIKELY(tree && tree->type()==Object::custom))
 		return static_cast<const CustomObject*>(tree)->value();
 	else {
 		qDebug() << "trying to return as a custom object something that it is not:" << (tree ? tree->toString() : "null");
@@ -898,7 +932,7 @@ static void print_dom(const QDomNode& in, int ind)
 	else
 		qDebug("%s%s", qPrintable(a), qPrintable(in.toElement().tagName()));
 	
-	for(unsigned int i=0 ; i<in.childNodes().length(); i++){
+	for(int i=0 ; i<in.childNodes().length(); i++){
 		if(in.childNodes().item(i).isElement())
 			print_dom(in.childNodes().item(i), ind+1);
 	}
